//+---------------------------------------------------------------------------------+
//|                                               DummyLights                       |
//| by Elixe with MA colorization by fxdaytrader                                    |
//| MA filtering rules by NanningBob                                                |
//|                                                                                 |
//| V1.0                                                                            |
//| V1.1                                                                            |
//| ck : Added a second color bar to show price with respect to 24060 on H1 chart   |
//| Elixe : Simplified code, corrected H1 signal + no signal box                    |
//| V1.2                                                                            |
//| Elixe : Changed H1 logic to MA15 filtering                                      |
//| V1.3                                                                            |
//| Elixe : Added some options for drawing + sto filter                             |
//+---------------------------------------------------------------------------------+


#property indicator_chart_window
#property link "http://www.stevehopwoodforex.com"


extern string ma0          = "Colors H4";
extern color maUpUp        = DarkGreen;              // color used when price is above both MA
extern color maUpDown      = OliveDrab;       // color used when price > first MA & price < second MA
extern color maDownUp      = DarkGoldenrod;        // color used when price < first MA & price > second MA
extern color maDownDown    = Maroon;           // color used when price is below both MA


extern string ma0h1        = "Colors H1";
extern color h1StrongUp    = DarkGreen;              // color used when price is > ma240 & price < ma60 & sto < 20
extern color h1StrongDown  = Maroon;           // color used when price is below both MA
extern color noH1Signal    = DimGray;         

extern string sto1         = "H1 STO722 on H4 ranging";
extern int stoHigh         = 80;
extern int stoLow          = 20;

extern string ma1          = "Slow MA period";
extern int ma1Period       = 240;

extern string ma2          = "Fast MA period";
extern int ma2Period       = 60;

extern string ma3          = "Signal MA period";
extern int ma3Period       = 15;

int maMethod               = MODE_LWMA;
int maPrice                = PRICE_OPEN;

extern string s3           = "Size of H4 Bar";
extern int numBarsRightH4  = 2;
extern string s4           = "Size of H1 Bar";
extern int numBarsRightH1  = 1;
//
string   objPrefix         = "EDSEL_"; // H4 Color Bars
int init()
  {
//----
   deleteObjects(objPrefix);
   return(0);
  }
  
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   deleteObjects(objPrefix);
//----
   return(0);
  }
  
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
   double maSlow = iMA(NULL,PERIOD_H4,ma1Period,0,maMethod,maPrice,0);
   double maFast = iMA(NULL,PERIOD_H4,ma2Period,0,maMethod,maPrice,0);
   double maSlowH1 = iMA(NULL,PERIOD_H1,ma1Period,0,maMethod,maPrice,0);
   double maFastH1 = iMA(NULL,PERIOD_H1,ma2Period,0,maMethod,maPrice,0);

   double maSignalH1 = iMA(NULL,PERIOD_H1,ma3Period,0,maMethod,maPrice,0);
   double stoH1 = iStochastic(NULL, PERIOD_H1, 7, 2, 2, MODE_LWMA, 1, MODE_MAIN, 0);
   
   double   high          = WindowPriceMax();
   double   low           = WindowPriceMin(); 
   datetime left          = Time[0]+(Period()*60*2);
   datetime right         = left+(Period()*60*numBarsRightH4);
   datetime leftSignalH1     = right+(Period()*60);
   datetime rightSignalH1    = leftSignalH1+(Period()*60*numBarsRightH1);
   
   bool ranging = false;
   
   // H4 logic
   if (Bid >= maSlow && Bid >= maFast)
   {
      doBox(maUpUp, high, left, low, right,1); // if Bid above both ma GREEN
      ranging = false;
   }
   else if (Bid >= maSlow && Bid < maFast)
   {
      doBox(maUpDown, high, left, low, right,1);  // if Bid between MA above 240 OLIVE
      ranging = true;
   }
   else if (Bid < maSlow && Bid > maFast)
   {
      doBox(maDownUp, high, left, low, right,1); // if Bid between MA below 240 GOLDENROD
      ranging = true;
   }
   else if (Bid < maSlow && Bid < maFast)
   {
      doBox(maDownDown, high, left, low, right,1); // If Bid below both MA RED
      ranging = false;
   }
   else
   {
      doBox(CLR_NONE, high, left, low, right, 1);
      ranging = false;
   }

   // H1 signals
   if (ranging)
   {
      if (Bid < maSignalH1 && stoH1 < stoLow) doBox(h1StrongUp, high, leftSignalH1, low, rightSignalH1, 2);
      else if (Bid > maSignalH1  && stoH1 > stoHigh) doBox(h1StrongDown, high, leftSignalH1, low, rightSignalH1, 2);
      else doBox(CLR_NONE, high, leftSignalH1, low, rightSignalH1, 2);
   }
   else
   {
      if (Bid < maSignalH1 && Bid > maSlowH1 && Bid > maFastH1) doBox(h1StrongUp, high, leftSignalH1, low, rightSignalH1, 2);
      else if (Bid > maSignalH1 && Bid < maSlowH1 && Bid < maFastH1) doBox(h1StrongDown, high, leftSignalH1, low, rightSignalH1, 2);
      else doBox(CLR_NONE, high, leftSignalH1, low, rightSignalH1, 2);
   }

   return(0);
}

 


void doBox(color mColor, double high, datetime left, double low, datetime right, int i)
{
   bool created;
   created = ObjectCreate(objPrefix+i,OBJ_RECTANGLE, 0, left, high, right, low);
   if (!created)
   {
      ObjectSet(objPrefix+i,OBJPROP_TIME1, left);
      ObjectSet(objPrefix+i,OBJPROP_PRICE1, high);
      ObjectSet(objPrefix+i,OBJPROP_TIME2, right);
      ObjectSet(objPrefix+i,OBJPROP_PRICE2, low);
      ObjectSet(objPrefix+i, OBJPROP_BACK, True);
   }
   ObjectSet(objPrefix+i, OBJPROP_COLOR, mColor);  
   ObjectSet(objPrefix+i, OBJPROP_BACK, True);
   ObjectSet(objPrefix+i, OBJPROP_STYLE, STYLE_SOLID);
   
   if (mColor == CLR_NONE)
   {
     ObjectSet(objPrefix+i, OBJPROP_COLOR, noH1Signal);
     ObjectSet(objPrefix+i, OBJPROP_BACK, False);
     ObjectSet(objPrefix+i, OBJPROP_STYLE, STYLE_DOT);
     //return;
   }
   
   WindowRedraw();
}


void deleteObjects(string objPrefix) {
  for (int i=ObjectsTotal()-1; i>=0; i--) {
   if (StringFind(ObjectName(i),objPrefix) > -1) ObjectDelete(ObjectName(i));
  }
}

 